summaryrefslogtreecommitdiffstats
path: root/sys/dev/random
diff options
context:
space:
mode:
authorjulian <julian@FreeBSD.org>2007-10-20 23:23:23 +0000
committerjulian <julian@FreeBSD.org>2007-10-20 23:23:23 +0000
commit51d643caa6efc11780104da450ee36a818170f81 (patch)
tree705ce8283c36af96cf048c799a9c02ee91af62db /sys/dev/random
parent830ad96079c0199720ca93a683f2a4450afac014 (diff)
downloadFreeBSD-src-51d643caa6efc11780104da450ee36a818170f81.zip
FreeBSD-src-51d643caa6efc11780104da450ee36a818170f81.tar.gz
Rename the kthread_xxx (e.g. kthread_create()) calls
to kproc_xxx as they actually make whole processes. Thos makes way for us to add REAL kthread_create() and friends that actually make theads. it turns out that most of these calls actually end up being moved back to the thread version when it's added. but we need to make this cosmetic change first. I'd LOVE to do this rename in 7.0 so that we can eventually MFC the new kthread_xxx() calls.
Diffstat (limited to 'sys/dev/random')
-rw-r--r--sys/dev/random/harvest.c4
-rw-r--r--sys/dev/random/randomdev_soft.c2
2 files changed, 3 insertions, 3 deletions
diff --git a/sys/dev/random/randomdev_soft.c b/sys/dev/random/randomdev_soft.c
index 365f3ea..c03673a 100644
--- a/sys/dev/random/randomdev_soft.c
+++ b/sys/dev/random/randomdev_soft.c
@@ -181,7 +181,7 @@ random_yarrow_init(void)
mtx_init(&harvest_mtx, "entropy harvest mutex", NULL, MTX_SPIN);
/* Start the hash/reseed thread */
- error = kthread_create(random_kthread, NULL,
+ error = kproc_create(random_kthread, NULL,
&random_kthread_proc, RFHIGHPID, 0, "yarrow");
if (error != 0)
panic("Cannot create entropy maintenance thread.");
OpenPOWER on IntegriCloud
diff --git a/sys/dev/random/harvest.c b/sys/dev/random/harvest.c
index d783065..aacba32 100644
--- a/sys/dev/random/harvest.c
+++ b/sys/dev/random/harvest.c
@@ -120,7 +120,7 @@ read_random_phony(void *buf, int count)
return (count);
}
/* Helper routine to enable kthread_exit() to work while the module is
* being (or has been) unloaded.
* This routine is in this file because it is always linked into the kernel,
* and will thus never be unloaded. This is critical for unloadable modules
@@ -130,6 +130,6 @@ void
random_set_wakeup_exit(void *control)
{
wakeup(control);
- kthread_exit(0);
+ kproc_exit(0);
/* NOTREACHED */
}
@@ -120,7 +120,7 @@ read_random_phony(void *buf, int count)
return (count);
}
-/* Helper routine to enable kthread_exit() to work while the module is
+/* Helper routine to enable kproc_exit() to work while the module is
* being (or has been) unloaded.
* This routine is in this file because it is always linked into the kernel,